@@ -219,15 +219,14 @@ class Bookmarks:
         if not start_obj:
             return []
 
-        docRoles = [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_DOCUMENT_WEB]
-        if start_obj.getRole() in docRoles:
+        if self._script.utilities.isDocument(start_obj):
             return []
 
         path = []
         path.append(start_obj.getIndexInParent())
         p = start_obj.parent
         while p:
-            if p.getRole() in docRoles:
+            if self._script.utilities.isDocument(p):
                 path.reverse()
                 return path
             path.append(p.getIndexInParent())
